meegkit.cca
===========

.. automodule:: meegkit.cca

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      cca_crossvalidate
      mcca
      nt_cca
      whiten
      whiten_nt
      whiten_svd
      whiten_zca
   
   

   
   
   

   
   
   



